//
//  YHFamilyInfoUpdateViewController.swift
//  galaxy
//
//  Created by edy on 2024/8/17.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import AttributedString

enum YHFamilyMemberRelationType: Int {
    case none = 0
    case mainApplicant = 1
    case spouse = 2
    case child = 3
}

class YHFamilyInfoUpdateViewController: YHBaseViewController {
    
    var relation:YHFamilyMemberRelationType = .mainApplicant
    var isInfoEditing: Bool = false
    
    var items: [[YHFamilyInfoItem]] = []

    lazy var tableView: UITableView = {
        let tableView = UITableView(frame:.zero, style:.grouped)
        tableView.estimatedSectionHeaderHeight = 16.0
        tableView.estimatedSectionFooterHeight = 0.01
        tableView.contentInsetAdjustmentBehavior = .never
        tableView.showsVerticalScrollIndicator = false
        tableView.separatorStyle = .none
        tableView.delegate = self
        tableView.dataSource = self
        tableView.backgroundColor = UIColor(hex: 0xF8F9FB)
        tableView.register(UITableViewCell.self, forCellReuseIdentifier: "UITableViewCell")
        tableView.register(YHIFamilyInfoListCell.self, forCellReuseIdentifier: YHIFamilyInfoListCell.cellReuseIdentifier)
        return tableView
    }()
    
    lazy var bottomView: UIView = {
        let view = UIView()
        view.backgroundColor = .white
        
        let cancelBtn = UIButton()
        cancelBtn.backgroundColor = UIColor.init(hex: 0xF8F9FB)
        cancelBtn.setTitle("取消", for: .normal)
        cancelBtn.setTitleColor(.init(hex: 0x222222), for: .normal)
        cancelBtn.titleLabel?.font = UIFont.PFSC_M(ofSize: 15)
        cancelBtn.addTarget(self, action: #selector(didCancelBtnClicked), for: .touchUpInside)
        cancelBtn.layer.cornerRadius = kCornerRadius3
        view.addSubview(cancelBtn)
        
        let confirmBtn = UIButton()
        confirmBtn.backgroundColor = .brandMainColor
        confirmBtn.setTitle("确认", for: .normal)
        confirmBtn.setTitleColor(.white, for: .normal)
        confirmBtn.titleLabel?.font = UIFont.PFSC_M(ofSize: 15)
        confirmBtn.addTarget(self, action: #selector(didConfirmBtnClicked), for: .touchUpInside)
        confirmBtn.layer.cornerRadius = kCornerRadius3
        view.addSubview(confirmBtn)
        
        cancelBtn.snp.makeConstraints { make in
            make.top.equalTo(10)
            make.left.equalTo(16)
            make.height.equalTo(44)
            make.width.equalTo(86)
        }
        
        confirmBtn.snp.makeConstraints { make in
            make.top.equalTo(10)
            make.right.equalTo(-16)
            make.height.equalTo(44)
            make.left.equalTo(cancelBtn.snp.right).offset(10)
        }

        return view
    }()
    
    override func viewDidLoad() {
        
        super.viewDidLoad()
        self.gk_navTitle = "家庭信息确认"
        self.view.backgroundColor = .white
        self.view.addSubview(self.tableView)
        self.view.addSubview(self.bottomView)

        self.tableView.snp.makeConstraints { make in
            make.left.right.equalToSuperview()
            make.top.equalTo(k_Height_NavigationtBarAndStatuBar+16)
            make.bottom.equalTo(self.bottomView.snp.top)
        }
        self.bottomView.snp.makeConstraints { make in
            make.left.right.bottom.equalToSuperview()
            make.height.equalTo(98)
        }
        self.getData()
    }
    
    @objc func didCancelBtnClicked() {
        
    }
    
    @objc func didConfirmBtnClicked() {
        
    }
    
    func getData() {
        
        items.removeAll()
        
        let isEditMode = self.isInfoEditing
        let isShowPreviousInfo = false
        
        // arr1 信息核实
        var arr1 = [YHFamilyInfoItem]()

        if self.relation == .mainApplicant {
            
            let name = "张全蛋张全蛋张全蛋张全蛋张全蛋张全蛋张全蛋张全蛋张全蛋张全蛋张全蛋张全蛋张全蛋张全蛋张全蛋张全蛋"
            let mainApplicantNameInfo =  YHFamilyInfoItem(id: .mainApplicantName,
                                                          action: .edit,
                                                          isMust: true,
                                                          title: "主申请人姓名",
                                                          value: name,
                                                          previousTitle: "原主申人姓名",
                                                          previousValue: name,
                                                          isEditMode: isEditMode,
                                                          isShowPreviousInfo: isShowPreviousInfo)
            arr1.append(mainApplicantNameInfo)
            
        } else if self.relation == .spouse {
            let name = "李斯"
            let spouseNameInfo = YHFamilyInfoItem(id: .spouseName,
                                                  action: .edit,
                                                  isMust: true,
                                                  title: "配偶姓名",
                                                  value: name,
                                                  previousTitle: "原配偶姓名",
                                                  previousValue: name,
                                                  isEditMode: isEditMode,
                                                  isShowPreviousInfo: isShowPreviousInfo)
           arr1.append(spouseNameInfo)
            
        } else if self.relation == .child {
            let name = "张晓蛋"
            let childNameInfo =  YHFamilyInfoItem(id: .childName,
                                                  action: .edit,
                                                  isMust: true,
                                                  title: "子女姓名",
                                                  value: name,
                                                  previousTitle: "原子女姓名",
                                                  previousValue: name,
                                                  isEditMode: isEditMode,
                                                  isShowPreviousInfo: isShowPreviousInfo)
           arr1.append(childNameInfo)
        }
       
        let firsName = "ZH"
        let firstNameInfo =  YHFamilyInfoItem(id: .firstName,
                                              action: .edit,
                                              isMust: true,
                                              title: "姓(拼音)",
                                              value: firsName,
                                              previousTitle: "原姓(拼音)",
                                              previousValue: firsName,
                                              isEditMode: isEditMode,
                                              isShowPreviousInfo: isShowPreviousInfo)
        arr1.append(firstNameInfo)
        
        let lastName = "ZHANGZ"
        let lastNameInfo =  YHFamilyInfoItem(id: .lastName,
                                             action: .edit,
                                             isMust: true,
                                             title: "名(拼音)",
                                             value: lastName,
                                             previousTitle: "原名(拼音)",
                                             previousValue: lastName,
                                             isEditMode: isEditMode,
                                             isShowPreviousInfo: isShowPreviousInfo)
        arr1.append(lastNameInfo)
        
        
        if self.relation != .child { // 子女无婚姻状况一栏
            let marriage = "已婚"
            let marriageInfo = YHFamilyInfoItem(id: .marriage,
                                                action: .select,
                                                isMust: true,
                                                title: "婚姻状况",
                                                value: marriage,
                                                previousTitle: "原婚姻状况",
                                                previousValue: marriage,
                                                isEditMode: isEditMode,
                                                isShowPreviousInfo: isShowPreviousInfo)
            arr1.append(marriageInfo)
        }
        
        let birthNation = "国内"
        let options = [YHFamilyInfoOption(value: "国内", isSelect: true),
                       YHFamilyInfoOption(value: "国外", isSelect: false)]
        let birthNationInfo =   YHFamilyInfoItem(id: .birthNation,
                                                 action: .choice,
                                                 isMust: true,
                                                 title: "出生国家/地区",
                                                 value: birthNation,
                                                 previousTitle: "原出生国家/地区",
                                                 previousValue: birthNation,
                                                 options: options,
                                                 isEditMode: isEditMode,
                                                 isShowPreviousInfo: isShowPreviousInfo)
        arr1.append(birthNationInfo)
        
        let birthPlace = "上海市市辖区"
        let birthPlaceInfo =  YHFamilyInfoItem(id: .birthPlace,
                                               action: .select,
                                               isMust: true,
                                               title: "出生地",
                                               value: birthPlace,
                                               previousTitle: "原出生地",
                                               previousValue: birthPlace,
                                               isEditMode: isEditMode,
                                               isShowPreviousInfo: isShowPreviousInfo)
        arr1.append(birthPlaceInfo)
        
        let declareNation = "中国-CHINA"
        let declareNationInfo =  YHFamilyInfoItem(id: .declareNation,
                                                  action: .select,
                                                  isMust: true,
                                                  title: "申报国籍",
                                                  value: declareNation,
                                                  previousTitle: "原申报国籍",
                                                  previousValue: declareNation,
                                                  isEditMode: isEditMode,
                                                  isShowPreviousInfo: isShowPreviousInfo)
        arr1.append(declareNationInfo)
        
        let occupation = "总监"
        let occupationInfo =  YHFamilyInfoItem(id: .occupation,
                                               action: .edit,
                                               isMust: true,
                                               title: "职业",
                                               value: occupation,
                                               previousTitle: "原职业",
                                               previousValue: occupation,
                                               isEditMode: isEditMode,
                                               isShowPreviousInfo: isShowPreviousInfo)
        arr1.append(occupationInfo)
        
        let hongkongId = "3231235123512"
        let hongkongIdInfo =  YHFamilyInfoItem(id: .hongKongId,
                                               action: .edit,
                                               isMust: true,
                                               title: "香港身份证号",
                                               value: hongkongId,
                                               previousTitle: "原香港身份证号",
                                               previousValue: hongkongId,
                                               isEditMode: isEditMode,
                                               isShowPreviousInfo: isShowPreviousInfo)
        arr1.append(hongkongIdInfo)
        
        
        
        // arr2 递交证件信息
        var arr2 = [YHFamilyInfoItem]()
        let travelCerType = "港澳通行证"
        let travelCerInfo = YHFamilyInfoItem(id: .travelCertificateType,
                                               action: .select,
                                               isMust: true,
                                               title: "申报旅行证件",
                                               value: travelCerType,
                                               previousTitle: "原申报旅行证件",
                                               previousValue: travelCerType,
                                               isEditMode: false,
                                               isShowPreviousInfo: false)
        arr2.append(travelCerInfo)
        
        let cerId = "2351235234523542"
        let cerIdInfo = YHFamilyInfoItem(id: .travelCertificateId,
                                         action: .edit,
                                         isMust: true,
                                         title: "证件号",
                                         value: cerId,
                                         previousTitle: "原证件号",
                                         previousValue: cerId,
                                         isEditMode: false,
                                         isShowPreviousInfo: false)
        arr2.append(cerIdInfo)
        
        
        // 信息核实
        items.append(arr1)
        // 递交证件信息
        items.append(arr2)
        
        self.tableView.reloadData()
    }
    
    func updateData() {
        let isEditMode = self.isInfoEditing
        let isShowPreviousInfo = false
        if let arr1 = items.first {
            for item in arr1 {
                item.isEditMode = isEditMode
                if !isEditMode, !item.previousValue.isEmpty, item.previousValue != item.value {
                    item.isShowPreviousInfo = true
                } else {
                    item.isShowPreviousInfo = false

                }
            }
        }
        self.tableView.reloadData()
    }
}

extension YHFamilyInfoUpdateViewController: UITableViewDelegate, UITableViewDataSource {
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return items.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        let cell = tableView.dequeueReusableCell(withIdentifier: YHIFamilyInfoListCell.cellReuseIdentifier, for: indexPath) as! YHIFamilyInfoListCell
        
        if indexPath.row == 0 {
            // 标题
            let title: ASAttributedString = .init("信息核实", .font(UIFont.PFSC_M(ofSize: 17)),.foreground(UIColor.mainTextColor))
            cell.titleLabel.attributed.text = title
            cell.modifyBtn.isHidden = false
            cell.isEditState = self.isInfoEditing
            cell.editBlock = {
                [weak self] isEdit in
                guard let self = self else { return }
                self.isInfoEditing = isEdit
                self.updateData()
            }
            
        } else {
            
            let title: ASAttributedString = .init("递交证件信息", .font(UIFont.PFSC_M(ofSize: 17)),.foreground(UIColor.mainTextColor))
            let subtitle: ASAttributedString = .init("(如需更换，请联系您的生活管家)", .font(UIFont.PFSC_R(ofSize: 13)),.foreground(UIColor.mainTextColor(alpha: 0.5)))
            cell.titleLabel.attributed.text = title + subtitle
            cell.modifyBtn.isHidden = true

        }
        
        if 0 <= indexPath.row && indexPath.row < items.count {
            let arr = items[indexPath.row]
            cell.updateItems(arr)
        }
        return cell
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        return UITableView.automaticDimension
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        
        if 0 <= indexPath.section && indexPath.section < items.count {
            
        }
    }
    
    private func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> CGFloat {
        return 0.01
    }
    
    private func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> CGFloat {
        return 0.01
    }
    
    func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> UIView? {
        
        let view = UIView()
        return view
    }
    
    func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> UIView? {
        
        let view = UIView()
        return view
    }
}
