//
//  YHIFamilyInfoListCell.swift
//  galaxy
//
//  Created by edy on 2024/8/17.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import AttributedString

enum YHFamilyInfoType: Int {
    case none = 0
    case mainApplicantName = 1
    case firstName = 2
    case lastName = 3
    case marriage = 4
    case birthNation = 5
    case birthPlace = 6
    case declareNation = 7
    case occupation = 8
    case hongKongId = 9
    case travelCertificateType = 10
    case travelCertificateId = 11
    case childName = 12
    case spouseName = 13
}

enum YHFamilyInfoActionType: Int {
    case none = 0
    case edit = 1    // 输入框编辑
    case select = 2  // 弹出弹窗选择
    case choice = 3  // 按钮多项选择
}

class YHFamilyInfoOption {
    var value: String = ""
    var isSelect: Bool = false
    
    init(value: String, isSelect: Bool) {
        self.value = value
        self.isSelect = isSelect
    }
}

class YHFamilyInfoItem {
    var id: YHFamilyInfoType = .none
    var action:YHFamilyInfoActionType = .none
    var isMust: Bool = false
    var title: String = ""
    var value: String = ""
    var previousTitle: String = ""
    var previousValue: String = ""
    var options:[YHFamilyInfoOption] = []
    var isEditMode: Bool = false
    var isShowPreviousInfo: Bool = false
    
    required init() {
        
    }
    
    init(id: YHFamilyInfoType, action: YHFamilyInfoActionType, isMust: Bool, title: String, value: String, previousTitle: String, previousValue: String, options: [YHFamilyInfoOption] = [], isEditMode: Bool, isShowPreviousInfo: Bool) {
        self.id = id
        self.action = action
        self.isMust = isMust
        self.title = title
        self.value = value
        self.previousTitle = previousTitle
        self.previousValue = previousValue
        self.isEditMode = isEditMode
        self.isShowPreviousInfo = isShowPreviousInfo
        self.options = options
    }
}

class YHIFamilyInfoListCell: UITableViewCell {

    static let cellReuseIdentifier = "YHIFamilyInfoListCell"
    
    var isEditState: Bool = false {
        didSet {
            let text = self.isEditState ? "完成" : "修改"
            self.modifyBtn.setTitle(text, for: .normal)
        }
    }
    var editBlock:((Bool)->())?
    
    lazy var whiteView: UIView = {
        let view = UIView()
        view.backgroundColor = .white
        view.layer.cornerRadius = kCornerRadius6
        return view
    }()
    
    lazy var titleLabel: UILabel = {
        let label = UILabel()
        label.numberOfLines = 0
        return label
    }()
    
    lazy var modifyBtn: UIButton = {
        let btn = UIButton()
        btn.titleLabel?.font = UIFont.PFSC_R(ofSize: 14)
        btn.setTitleColor(.brandMainColor, for: .normal) 
        btn.setTitle("修改", for: .normal)
        btn.addTarget(self, action: #selector(didModifyBtnClicked), for: .touchUpInside)
        return btn
    }()
    
    lazy var itemsContentView: UIView = {
        let view = UIView()
        return view
    }()
    
    required init?(coder: NSCoder) {
        super.init(coder: coder)
    }
    
    override init(style: UITableViewCell.CellStyle, reuseIdentifier: String?) {
        super.init(style: style, reuseIdentifier: reuseIdentifier)
        setupUI()
    }
    
    @objc func didModifyBtnClicked() {
        editBlock?(!self.isEditState)
    }
    
    func setupUI() {
        
        self.selectionStyle = .none
        self.backgroundColor = .clear
        self.contentView.backgroundColor = .clear
        contentView.addSubview(whiteView)
        whiteView.addSubview(titleLabel)
        whiteView.addSubview(modifyBtn)
        whiteView.addSubview(itemsContentView)
        
        whiteView.snp.makeConstraints { make in
            make.top.equalTo(16)
            make.left.equalTo(16)
            make.right.equalTo(-16)
            make.bottom.equalTo(-16)
        }
        
        titleLabel.snp.makeConstraints { make in
            make.top.equalTo(18)
            make.left.equalTo(18)
            make.right.equalTo(-18)
        }
        
        modifyBtn.snp.makeConstraints { make in
            make.top.equalTo(18)
            make.right.equalTo(-18)
            make.size.equalTo(CGSize(width: 28, height: 20))
        }
        
        itemsContentView.snp.makeConstraints { make in
            make.top.equalTo(titleLabel.snp.bottom).offset(12)
            make.left.equalTo(18)
            make.right.equalTo(-18)
            make.bottom.equalTo(0)
        }

    }
    
    func updateItems(_ items:[YHFamilyInfoItem]) {
        itemsContentView.removeSubviews()
        
        var lastItemView:UIView? = nil
        for (index, item) in items.enumerated() {
            var itemView:UIView? = YHInfoItemView(frame: .zero)
            if item.action == .choice {
                itemView = YHInfoOptionView(frame: .zero)
            }
            if let itemView = itemView as? YHInfoItemView {
                itemsContentView.addSubview(itemView)
                itemView.updateItem(item)
                
            } else if let itemView = itemView as? YHInfoOptionView {
                itemsContentView.addSubview(itemView)
                itemView.updateItem(item)
            }
            
            if let itemView = itemView {
                itemView.snp.makeConstraints { make in
                    make.left.right.equalTo(0)
                    if let lastView = lastItemView {
                        make.top.equalTo(lastView.snp.bottom)
                    } else {
                        make.top.equalTo(itemsContentView.snp.top)
                    }
                    
                    if index == items.count-1 {
                        make.bottom.equalTo(itemsContentView.snp.bottom)
                    }
                }
                lastItemView = itemView
            }
            
        }
        self.setNeedsLayout()
        self.layoutIfNeeded()
    }

}
